/*
 * rfEasylinkTx.c
 *
 * RF periodic transmission using TI RTOS with Sub-1GHz transmission every 2 seconds
 *
 * Copyright (C) 2015 Texas Instruments Incorporated - http://www.ti.com/ 
 * 
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/

/***** Includes *****/
#include <stdlib.h>
#include <xdc/std.h>
#include <xdc/cfg/global.h>
#include <xdc/runtime/System.h>

#include <ti/sysbios/BIOS.h>
#include <ti/sysbios/knl/Task.h>

/* Drivers */
#include <ti/drivers/rf/RF.h>
#include <ti/drivers/PIN.h>

/* Board Header files */
#include "Board.h"

#include "smartrf_settings/smartrf_settings.h"

//MS 2. Oct'15
#include "sce/scif_framework.h"
#include "sce/scif_osal_tirtos.h"
#include "sce/scif.h"
//MS

extern uint8_t TXpacket[];
extern uint8_t TXbytes[];
extern uint8_t TXdataLength;
extern uint16_t  packetLength, TmodeByteLength;

/* Pin driver handle */
static PIN_Handle ledPinHandle;
static PIN_State ledPinState;

/*
 * Application LED pin configuration table:
 *   - All LEDs board LEDs are off.
 */
PIN_Config pinTable[] =
{
    Board_LED3 | PIN_GPIO_OUTPUT_EN | PIN_GPIO_LOW | PIN_PUSHPULL | PIN_DRVSTR_MAX,
    Board_LED4 | PIN_GPIO_OUTPUT_EN | PIN_GPIO_LOW | PIN_PUSHPULL | PIN_DRVSTR_MAX,
	Board_KEY_RIGHT  | PIN_INPUT_EN | PIN_PULLUP | PIN_IRQ_NEGEDGE,
	Board_KEY_LEFT   | PIN_INPUT_EN | PIN_PULLUP | PIN_IRQ_NEGEDGE,
    PIN_TERMINATE
};


/***** Defines *****/
#define TX_TASK_STACK_SIZE 1024
#define TX_TASK_PRIORITY   2

/* TX Configuration */
#define NUMBER_OF_PACKETS       10
#define PAYLOAD_LENGTH          255
//#define PACKET_INTERVAL 	4000000*0.5f
#define PACKET_INTERVAL 	96000000*0.5f //=12sec;  09. Dec'15
#define BV(n)               (1 << (n))

#define DISABLE_LOW_POWER   0

#include <ti/drivers/UART.h>
#include <ti/drivers/uart/UARTCC26XX.h>
#include "string.h"
#include "stdio.h"
#include "yvals.h"
#include <driverlib/aux_adc.h> //for ADC calibration operations

#include "wmbus/mbus_packet.h"


// Task data
Task_Struct myTask;
Char myTaskStack[1024];

// UART driver objects
UART_Handle uHandle;
UART_Params uParams;
char pLine[21], command = '0';

// Semaphore used to wait for Sensor Controller task ALERT event
static Semaphore_Struct semScTaskAlert;

void scCtrlReadyCallback(void);
void scTaskAlertCallback(void);

//ADC calculation objects
uint32_t calADC12_gain=0, lmt70_HeatSensor=0, lmt70_RoomSensor=0, lmt70_CalInput=0;
int8_t calADC12_offset;
float temp1_LMT70lin,temp2_LMT70lin, temp1_LMT70dual,temp2_LMT70dual;
float a = -7.857923E-06, b = -1.777501E-01, c = 2.046398E+02;

/*******************************************************************************
*               Packet Examples from EN13757-4:2014
*   Packet S2:  0F 44 AE 0C 78 56 34 12 01 07 44 47 78 0B 13 43 65 87 1E 6D     (20 Bytes) S- and T-Modes with Format A
*   Packet C2:  14 44 AE 0C 78 56 34 12 01 07 8C 20 27 78 0B 13 43 65 87 7A C5  (21 Bytes) all other Modes with Format B
*/

uint8_t wMBusPacketC[]= {0x14,PACKET_C_FIELD, 0xAE, 0x0C, PACKET_CI_FIELD, 0x56, 0x34, 0x12, MAN_ID, MAN_VER, 0x8C, 0x20, 0x27, PACKET_CI_FIELD, 0x0B, 0x13, 0x43, 0x65, 0x87, 0x00, 0x00/*0x7A, 0xC5*/}; //C2-Mode
//volatile unsigned int  mode = 3; //C-mode
//volatile unsigned int  mode = 2; //T-mode
volatile unsigned int  mode = 0; //S-mode
extern uint16_t  packetLength, TmodeByteLength;
extern uint8_t TXbytes[];

void taskFxn(UArg a0, UArg a1) {

    // Initialize UART parameters
    UART_Params_init(&uParams);
    uParams.baudRate      = 115200;
    //uParams.baudRate      = 9600;
    uParams.writeDataMode = UART_DATA_BINARY;
    uParams.dataLength    = UART_LEN_8;
    uParams.stopBits      = UART_STOP_ONE;
    uParams.writeMode     = UART_MODE_BLOCKING;
    uParams.readMode     = UART_MODE_BLOCKING;

    // Open UART
    uHandle = UART_open(Board_UART, &uParams);

    // Initialize the Sensor Controller
    scifOsalInit();
    scifOsalRegisterCtrlReadyCallback(scCtrlReadyCallback);
    scifOsalRegisterTaskAlertCallback(scTaskAlertCallback);
    scifInit(&scifDriverSetup);

    // Set the Sensor Controller task tick interval to 4 seconds (was 1/16 second)
    scifStartRtcTicksNow(0x00010000 * 4); //was /16

    // Start the Sensor Controller task (not to be confused with OS tasks)
    scifStartTasksNbl(BV(SCIF_LMT70POWER_READ_TASK_ID));

     // Read out ADC calibration values for Analog Output from LMT70 to CC1310 ADC
    calADC12_offset = AUXADCGetAdjustmentOffset(AUXADC_REF_FIXED);
    calADC12_gain = AUXADCGetAdjustmentGain(AUXADC_REF_FIXED);
    
    
    // Main loop
    while (1) {
 
        // Wait for an ALERT callback
        Semaphore_pend(Semaphore_handle(&semScTaskAlert), BIOS_WAIT_FOREVER);

        // Clear the ALERT interrupt source
        scifClearAlertIntSource();

#ifdef SCIF_FLOW_METER_DIO_OP_DIFF
        // Print TDC values
        sprintf(pLine + 0,  "%4d ",  scifTaskData.lmt70powerRead.output.pTdcValues[0]);
        sprintf(pLine + 5,  "%4d\n", scifTaskData.lmt70powerRead.output.pTdcValues[1]);
#else
        // Print ADC values = Analog Output from LMT70 to CC1310 ADC
        calADC12_offset = AUXADCGetAdjustmentOffset(AUXADC_REF_FIXED);  //read out value stored in CC1310 FCFG1
        calADC12_gain = AUXADCGetAdjustmentGain(AUXADC_REF_FIXED);      //read out value stored in CC1310 FCFG1
        
        lmt70_HeatSensor = AUXADCAdjustValueForGainAndOffset(scifTaskData.lmt70powerRead.output.adcVal1, calADC12_gain, calADC12_offset);
        lmt70_RoomSensor = AUXADCAdjustValueForGainAndOffset(scifTaskData.lmt70powerRead.output.adcVal2, calADC12_gain, calADC12_offset);
        //lmt70_CalInput = AUXADCAdjustValueForGainAndOffset(scifTaskData.lmt70powerRead.output.adcVal3, calADC12_gain, calADC12_offset);
        
        //Linear Interpolation method for LMT70 temp. calculation
        // Thus the final equation used to calculate the measured temperature (TM) in the range between 20C and 30C is: TM = m  VTAO + b 
        // TM = 0.193 C/mV  VTAO + 212.009C
        // where VTAO is in mV and TM is in C.
        temp1_LMT70lin = -0.193 * lmt70_HeatSensor * 1440 / 4095 + 212.009;
        temp2_LMT70lin = -0.193 * lmt70_RoomSensor * 1440 / 4095 + 212.009;
        
        temp1_LMT70dual = a * lmt70_HeatSensor * lmt70_HeatSensor * 1440*1440/(4095*4095) + b * lmt70_HeatSensor * 1440 / 4095 + c;
        temp2_LMT70dual = a * lmt70_RoomSensor * lmt70_RoomSensor * 1440*1440/(4095*4095)+  b * lmt70_RoomSensor * 1440 / 4095 + c;
        // TM = a (VTAO)2+ b (VTAO) + c  if Second Order Transfer Function is used (instead of Linear)
        // a = -7.857923E-06; b = -1.777501E-01; c = 2.046398E+02
                
   //   sprintf(pLine + 0,  "%4d ",  scifTaskData.lmt70powerRead.output.adcVal1);  //use 4d for Decimal - ADC read out value
   //   sprintf(pLine + 5,  "%4d\n",  scifTaskData.lmt70powerRead.output.adcVal2);      //use 4d for Decimal - ADC read out value; 23.9.15
        
        
        sprintf(pLine + 0,  "%4d ",  lmt70_HeatSensor);  //use 4d for Decimal
        sprintf(pLine + 5,  "%4d ",  lmt70_RoomSensor);      //use 4d for Decimal 23.9.15
      //  sprintf(pLine + 10,  "%4d\n",  scifTaskData.lmt70powerRead.output.adcVal3);      //Calibration Input, use 4d for Decimal 28.9.15
//        sprintf(pLine + 10, "%4d ",  scifTaskData.flowMeter.output.result1n);
//        sprintf(pLine + 15, "%4d\n", scifTaskData.flowMeter.output.result1p);
#endif
        
       //  UART_read(uHandle, &command, 1);
         
         
        // Send it over the UART
        UART_write(uHandle, pLine, strlen(pLine));

        // Acknowledge the alert event
        scifAckAlertEvents();
    }

} // taskFxn


void scCtrlReadyCallback(void) {

} // scCtrlReadyCallback


void scTaskAlertCallback(void) {

    // Wake up the OS task
    Semaphore_post(Semaphore_handle(&semScTaskAlert));

} // scTaskAlertCallback

//MS 1. Oct'15

/***** Prototypes *****/
static void txTaskFunction(UArg arg0, UArg arg1);



/***** Variable declarations *****/
static Task_Params txTaskParams;
static Task_Struct txTask;
static uint8_t txTaskStack[TX_TASK_STACK_SIZE];

static RF_Object rfObject;
static RF_Handle rfHandle;

uint32_t time;
static uint8_t packet[PAYLOAD_LENGTH];
//static uint16_t seqNumber;
static uint32_t packetCounter;
static PIN_Handle pinHandle;


/***** Function definitions *****/
void TxTask_init(PIN_Handle inPinHandle)
{
    pinHandle = inPinHandle;

    Task_Params_init(&txTaskParams);
    txTaskParams.stackSize = TX_TASK_STACK_SIZE;
    txTaskParams.priority = TX_TASK_PRIORITY;
    txTaskParams.stack = &txTaskStack;
    txTaskParams.arg0 = (UInt)12000000;   //MS: 9 Dec.'15; 12 seconds TX period (UInt)1000000;

    Task_construct(&txTask, txTaskFunction, &txTaskParams, NULL);
}

static void txTaskFunction(UArg arg0, UArg arg1)
{
    uint32_t time;
    RF_Params rfParams;
    RF_Params_init(&rfParams);

    RF_cmdPropTx.pktLen = PAYLOAD_LENGTH;
    RF_cmdPropTx.pPkt = packet;
    RF_cmdPropTx.startTrigger.triggerType = TRIG_ABSTIME;
    RF_cmdPropTx.startTrigger.pastTrig = 1;
    RF_cmdPropTx.startTime = 0;

    /* Request access to the radio */
    rfHandle = RF_open(&rfObject, &RF_prop, (RF_RadioSetup*)&RF_cmdPropRadioDivSetup, &rfParams);

    /* Set the frequency */
    RF_postCmd(rfHandle, (RF_Op*)&RF_cmdFs, RF_PriorityNormal, NULL);

    mode = WMbus_mode;
    while(1)
    {
        /****** STEP 4 - TX ********************************************************
        * 1. Create packet (with increasing sequence number and random content)
        * 2. Set absolute TX time to utilize automatic power management
        * 3. Send CMD_PROP_TX command with blocking RF driver call
        * 4. (Go to step 1. until NUMBER_OF_PACKETS packets sent)
        ****************************************************************************/
        packetCounter = 0;
        time = RF_getCurrentTime();
        while (packetCounter++ < NUMBER_OF_PACKETS)
        {
            /* 1. Create packet with incrementing sequence number and random payload */
        //    packet[0] = (uint8_t)(seqNumber >> 8);
        //    packet[1] = (uint8_t)(seqNumber++);
            uint8_t i;            
            
            if (mode == WMBUS_CMODE || mode == WMBUS_C2MODE || mode == WMBUS_NabefMODE || WMbus_mode == WMBUS_NcdMODE || WMbus_mode == WMBUS_NgMODE ||
					    		 	 WMbus_mode == WMBUS_FMODE ) {
			wMBusPacketC[16] = calADC12_offset; //(unsigned char) ((ui16wmbusACC_Counter&0x00FF0000)>>16);
			wMBusPacketC[17] = calADC12_gain >> 8; //(unsigned char) ((ui16wmbusACC_Counter&0x0000FF00)>>8);
			//wMBusPacketC[18] = calADC12_gain; //(unsigned char) (ui16wmbusACC_Counter&0x000000FF);                     
                       wMBusPacketC[18] = packetCounter; //(unsigned char) (ui16wmbusACC_Counter&0x000000FF);                     
                       
                                    /* MS 2. Oct'15: use LMT70 data  
            packet[2] = calADC12_offset;
            packet[3] = calADC12_gain >> 24;
            packet[4] = calADC12_gain >> 16;
            packet[5] = calADC12_gain >> 8;
            packet[6] = calADC12_gain;
    */
			packetLength = packetSize (wMBusPacketC[0]);
			encodeTXPacket(TXbytes, wMBusPacketC, packetLength);                            
            for (i = 0; i < packetLength; i++)  {
              packet[i] = TXbytes[i];               //wMBusPacketC[i-2];  //original: random data
               //MS 2. Oct'15: use LMT70 data        
            }            
	   }
             else if (mode == WMBUS_TMODE) { //0x04 1st Byte??
			TXpacket[13] = DIF_FIELD; //0x0B; need overwrite due to TXpacket->TXbytes->TXpacket handling
			TXpacket[14] = VIF_FIELD; //0x13;
			encodeTXPacket(TXbytes, TXpacket, TXdataLength);

			//calculate T-mode TXpacket length
			packetLength = packetSize (TXbytes[0]); //works for S-mode packet with Manchester in HW
			encodeTXBytesTmode(TXpacket, TXbytes, packetLength);
			TmodeByteLength = byteSize(2, 1, packetLength);
                        for (i = 0; i < TmodeByteLength; i++)  {
                          packet[i] = TXpacket[i];               //wMBusPacketC[i-2];  //original: random data
                          //MS 2. Oct'15: use LMT70 data        
                        }
		//	cc112xSpiWriteTxFifo(TXpacket, TmodeByteLength);
             }
             else if (mode == WMBUS_SMODE) {
		    encodeTXPacket(TXbytes, TXpacket, TXdataLength);
		    packetLength = packetSize (TXpacket[0]); //works for S-mode packet with Manchester in HW
			//cc112xSpiWriteTxFifo(TXbytes, packetLength);
                    for (i = 0; i < packetLength; i++)  {
                          packet[i] = TXbytes[i];               //wMBusPacketC[i-2];  //original: random data
                          //MS 2. Oct'15: use LMT70 data        
                    }
		}
          
            /* 2. Set absolute TX time to utilize automatic power management */
            time += PACKET_INTERVAL;
            RF_cmdPropTx.startTime = time;

            /* 3. Send packet */
            RF_Event result = RF_runCmd(rfHandle, (RF_Op*)&RF_cmdPropTx, RF_PriorityNormal);
            if (result != RF_EventCmdDone)
            {
                /* Error */
                while(1);
            }

            PIN_setOutputValue(pinHandle, Board_LED3,!PIN_getOutputValue(Board_LED3));
        }
    }
}

/*
 *  ======== main ========
 */
int main(void)
{
  
      Task_Params taskParams;

    // Optional: Prevent the system from entering standby to allow debugging
#if DISABLE_LOW_POWER
    Power_setConstraint(Power_SB_DISALLOW);
    Power_setConstraint(Power_IDLE_PD_DISALLOW);
#endif

    //*mode = WMBUS_CMODE;  
    // Initialize the PIN driver
    PIN_init(BoardGpioInitTable);

    // Configure the OS task
    Task_Params_init(&taskParams);
    taskParams.stack = myTaskStack;
    taskParams.stackSize = sizeof(myTaskStack);
    taskParams.priority = 3;
    Task_construct(&myTask, taskFxn, &taskParams, NULL);

    // Create the semaphore used to wait for Sensor Controller ALERT events
    Semaphore_Params semParams;
    Semaphore_Params_init(&semParams);
    semParams.mode = Semaphore_Mode_BINARY;
    Semaphore_construct(&semScTaskAlert, 0, &semParams);

  
    /* Call board init functions. */
 //   Board_initGeneral();

    /* Open LED pins */
    ledPinHandle = PIN_open(&ledPinState, pinTable);
    if(!ledPinHandle)
    {
        System_abort("Error initializing board LED pins\n");
    }

    /* Clear LED pins */
    PIN_setOutputValue(ledPinHandle, Board_LED3, 0);
    PIN_setOutputValue(ledPinHandle, Board_LED4, 0);

    /* Initialize task */
    TxTask_init(ledPinHandle);
    

    /* Start BIOS */
    BIOS_start();

    return (0);
}
